fnss.topologies.datacenter.DatacenterTopology.has_edge — FNSS 0.3.2 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »

# fnss.topologies.datacenter.DatacenterTopology.has_edge

`DatacenterTopology.` `has_edge`(u, v)

  Return True if the edge (u,v) is in the graph.

  Parameters : | u,v : nodes Nodes can be, for example, strings or numbers. Nodes must be hashable (and not None) Python objects.
  Returns : | edge_ind : bool True if edge is in the graph, False otherwise.

  Examples

  Can be called either using two nodes u,v or edge tuple (u,v)

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_path([0,1,2,3])
      >>> G.has_edge(0,1)  # using two nodes
      True
      >>> e = (0,1)
      >>> G.has_edge(*e)  #  e is a 2-tuple (u,v)
      True
      >>> e = (0,1,{'weight':7})
      >>> G.has_edge(*e[:2])  # e is a 3-tuple (u,v,data_dictionary)
      True

  The following syntax are all equivalent:

      >>> G.has_edge(0,1)
      True
      >>> 1 in G[0]  # though this gives KeyError if 0 not in G
      True

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »